@@ -326,7 +326,7 @@ class HttpIamAuthorizer(
         route: aws_cdk.aws_apigatewayv2.IHttpRoute,
         scope: constructs.Construct,
     ) -> aws_cdk.aws_apigatewayv2.HttpRouteAuthorizerConfig:
-        '''(experimental) (experimental) Bind this authorizer to a specified Http route.
+        '''(experimental) Bind this authorizer to a specified Http route.
 
         :param route: (experimental) The route to which the authorizer is being bound.
         :param scope: (experimental) The scope for any constructs created as part of the bind.
@@ -404,7 +404,7 @@ class HttpJwtAuthorizer(
         route: aws_cdk.aws_apigatewayv2.IHttpRoute,
         scope: constructs.Construct,
     ) -> aws_cdk.aws_apigatewayv2.HttpRouteAuthorizerConfig:
-        '''(experimental) (experimental) Bind this authorizer to a specified Http route.
+        '''(experimental) Bind this authorizer to a specified Http route.
 
         :param route: (experimental) The route to which the authorizer is being bound.
         :param scope: (experimental) The scope for any constructs created as part of the bind.
@@ -586,7 +586,7 @@ class HttpLambdaAuthorizer(
         route: aws_cdk.aws_apigatewayv2.IHttpRoute,
         scope: constructs.Construct,
     ) -> aws_cdk.aws_apigatewayv2.HttpRouteAuthorizerConfig:
-        '''(experimental) (experimental) Bind this authorizer to a specified Http route.
+        '''(experimental) Bind this authorizer to a specified Http route.
 
         :param route: (experimental) The route to which the authorizer is being bound.
         :param scope: (experimental) The scope for any constructs created as part of the bind.
@@ -809,7 +809,7 @@ class HttpUserPoolAuthorizer(
         route: aws_cdk.aws_apigatewayv2.IHttpRoute,
         scope: constructs.Construct,
     ) -> aws_cdk.aws_apigatewayv2.HttpRouteAuthorizerConfig:
-        '''(experimental) (experimental) Bind this authorizer to a specified Http route.
+        '''(experimental) Bind this authorizer to a specified Http route.
 
         :param route: (experimental) The route to which the authorizer is being bound.
         :param scope: (experimental) The scope for any constructs created as part of the bind.
@@ -999,7 +999,7 @@ class WebSocketLambdaAuthorizer(
         route: aws_cdk.aws_apigatewayv2.IWebSocketRoute,
         scope: constructs.Construct,
     ) -> aws_cdk.aws_apigatewayv2.WebSocketRouteAuthorizerConfig:
-        '''(experimental) (experimental) Bind this authorizer to a specified WebSocket route.
+        '''(experimental) Bind this authorizer to a specified WebSocket route.
 
         :param route: (experimental) The route to which the authorizer is being bound.
         :param scope: (experimental) The scope for any constructs created as part of the bind.
